==> react-hints-0.1.0.tgz: package/dist-es6/hint.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import { Popover, OverlayTrigger } from 'react-bootstrap';
import getStyles from './styles';
import getAbsoluteBoundingRect from './getAbsoluteBoundingRect';
import Portal from './portal';

var styleId = '____react-hint-styles___';
var styles = getStyles();

var Hint = function (_React$Component) {
  _inherits(Hint, _React$Component);

  function Hint() {
    _classCallCheck(this, Hint);

    var _this = _possibleConstructorReturn(this, (Hint.__proto__ || Object.getPrototypeOf(Hint)).call(this));

    _this.state = {
      style: {},
      isHidden: false
    };

    _this.width = 20;
    _this.height = 20;
    return _this;
  }

  _createClass(Hint, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      // add styles
      if (!document.getElementById(styleId)) {
        var head = document.head || document.getElementsByTagName('head')[0];
        var style = document.createElement('style');
        style.type = 'text/css';
        style.id = styleId;
        if (style.styleSheet) {
          style.styleSheet.cssText = styles;
        } else {
          style.appendChild(document.createTextNode(styles));
        }
        head.appendChild(style);
      }

      // other stuff
      if (this.props.id && localStorage['react-hint-' + this.props.id]) {
        this.setState({ isHidden: true });
      }
      this.update();

      window.addEventListener('resize', this.update.bind(this));
      window.addEventListener('load', this.update.bind(this));
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps() {
      this.update();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('resize', this.update.bind(this));
      window.removeEventListener('load', this.update.bind(this));
    }
  }, {
    key: 'update',
    value: function update() {
      var child = void 0,
          rect = void 0,
          offset = void 0,
          x = void 0,
          y = void 0;
      if (this.props.byID) {
        child = document.getElementById(this.props.byID);
      } else {
        child = ReactDOM.findDOMNode(this.refs.child);
      }
      if (!child) return;

      rect = getAbsoluteBoundingRect(child);
      offset = this.getDirectionBasedOffset(rect);

      x = offset.x;
      y = offset.y;

      this.setState({
        style: {
          top: y + 'px',
          left: x + 'px'
        }
      });
    }
  }, {
    key: 'render',
    value: function render() {
      if (this.state.isHidden || this.props.isHidden) {
        return this.props.children || false;
      }
      return React.createElement(
        'span',
        { className: '' },
        this.props.children ? React.createElement(
          'span',
          null,
          this.props.children
        ) : false,
        React.createElement(
          Portal,
          null,
          React.createElement(
            OverlayTrigger,
            {
              ref: 'popupOverlay',
              trigger: 'click',
              rootClose: true,
              placement: this.getPopupPlacement(),
              overlay: React.createElement(
                Popover,
                { className: 'react-hint-popover', id: 'hint' },
                React.createElement(
                  'span',
                  { style: { marginBottom: '10px', display: 'block' } },
                  this.props.message,
                  ' '
                ),
                React.createElement(
                  'button',
                  { className: 'btn btn-default btn-sm', onClick: this.onClose.bind(this) },
                  this.props.closeText || 'Got It!'
                )
              )
            },
            React.createElement(
              'a',
              { className: 'react-hint', style: this.state.style },
              React.createElement('div', { className: 'wave' }),
              React.createElement('div', { className: 'inner' })
            )
          )
        )
      );
    }
  }, {
    key: 'onClose',
    value: function onClose() {
      this.setState({ isHidden: true });
      this.refs.popupOverlay.hide();
      if (this.props.id) {
        localStorage['react-hint-' + this.props.id] = true;
      }
      if (this.props.onClose) {
        this.props.onClose();
      }
    }
  }, {
    key: 'getPopupPlacement',
    value: function getPopupPlacement() {
      return this.props.popupDirection || 'right';
    }
  }, {
    key: 'getDirectionBasedOffset',
    value: function getDirectionBasedOffset(rect) {
      var dir = this.props.position || 'topright';
      var x = rect.left;
      var y = rect.top;

      // decide position based on given position string
      if (dir === 'topright') {
        x = rect.right - this.width / 2;
        y = rect.top - this.height / 2;
      }
      if (dir === 'top') {
        x = rect.left + rect.width / 2 - this.width / 2;
        y = rect.top - this.height / 2;
      }
      if (dir === 'topleft') {
        x = rect.left - this.width / 2;
        y = rect.top - this.height / 2;
      }
      if (dir === 'left') {
        x = rect.left - this.width / 2;
        y = rect.top + rect.height / 2 - this.height / 2;
      }
      if (dir === 'bottomleft') {
        x = rect.left - this.width / 2;
        y = rect.bottom - this.height / 2;
      }
      if (dir === 'bottom') {
        x = rect.left + rect.width / 2 - this.width / 2;
        y = rect.bottom - this.height / 2;
      }
      if (dir === 'bottomright') {
        x = rect.right - this.width / 2;
        y = rect.bottom - this.height / 2;
      }
      if (dir === 'right') {
        x = rect.right - this.width / 2;
        y = rect.top + rect.height / 2 - this.height / 2;
      }

      // just add offsets, if any
      x += this.props.offsetX || 0;
      y += this.props.offsetY || 0;

      return { x: x, y: y };
    }
  }]);

  return Hint;
}(React.Component);

Hint.propTypes = process.env.NODE_ENV !== "production" ? {
  id: PropTypes.string.isRequired,
  message: PropTypes.node.isRequired,
  closeText: PropTypes.string,
  position: PropTypes.string,
  popupDirection: PropTypes.string,
  onClose: PropTypes.func,
  byID: PropTypes.string,
  isHidden: PropTypes.bool,

  children: PropTypes.node,
  offsetX: PropTypes.number,
  offsetY: PropTypes.number
} : {};

export default Hint;

==> react-hints-0.1.1.tgz: package/dist-es6/hint.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import { Popover, OverlayTrigger } from 'react-bootstrap';
import getStyles from './styles';
import getAbsoluteBoundingRect from './getAbsoluteBoundingRect';
import Portal from './portal';

var styleId = '____react-hint-styles___';
var styles = getStyles();

var Hint = function (_React$Component) {
  _inherits(Hint, _React$Component);

  function Hint() {
    _classCallCheck(this, Hint);

    var _this = _possibleConstructorReturn(this, (Hint.__proto__ || Object.getPrototypeOf(Hint)).call(this));

    _this.state = {
      style: {},
      isHidden: false
    };

    _this.width = 20;
    _this.height = 20;
    return _this;
  }

  _createClass(Hint, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      // add styles
      if (!document.getElementById(styleId)) {
        var head = document.head || document.getElementsByTagName('head')[0];
        var style = document.createElement('style');
        style.type = 'text/css';
        style.id = styleId;
        if (style.styleSheet) {
          style.styleSheet.cssText = styles;
        } else {
          style.appendChild(document.createTextNode(styles));
        }
        head.appendChild(style);
      }

      // other stuff
      if (this.props.id && localStorage['react-hint-' + this.props.id]) {
        this.setState({ isHidden: true });
      }
      this.update();

      window.addEventListener('resize', this.update.bind(this));
      window.addEventListener('load', this.update.bind(this));
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps() {
      this.update();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('resize', this.update.bind(this));
      window.removeEventListener('load', this.update.bind(this));
    }
  }, {
    key: 'update',
    value: function update() {
      var child = void 0,
          rect = void 0,
          offset = void 0,
          x = void 0,
          y = void 0;
      if (this.props.byID) {
        child = document.getElementById(this.props.byID);
      } else {
        child = ReactDOM.findDOMNode(this.refs.child);
      }
      if (!child) return;

      rect = getAbsoluteBoundingRect(child);
      offset = this.getDirectionBasedOffset(rect);

      x = offset.x;
      y = offset.y;

      this.setState({
        style: {
          top: y + 'px',
          left: x + 'px'
        }
      });
    }
  }, {
    key: 'render',
    value: function render() {
      if (this.state.isHidden || this.props.isHidden) {
        return this.props.children || false;
      }
      return React.createElement(
        'span',
        { className: '' },
        this.props.children ? React.cloneElement(this.props.children, { ref: 'child' }) : false,
        React.createElement(
          Portal,
          null,
          React.createElement(
            OverlayTrigger,
            {
              ref: 'popupOverlay',
              trigger: 'click',
              rootClose: true,
              placement: this.getPopupPlacement(),
              overlay: React.createElement(
                Popover,
                { className: 'react-hint-popover', id: 'hint' },
                React.createElement(
                  'span',
                  { style: { marginBottom: '10px', display: 'block' } },
                  this.props.message,
                  ' '
                ),
                React.createElement(
                  'button',
                  { className: 'btn btn-default btn-sm', onClick: this.onClose.bind(this) },
                  this.props.closeText || 'Got It!'
                )
              )
            },
            React.createElement(
              'a',
              { className: 'react-hint', style: this.state.style },
              React.createElement('div', { className: 'wave' }),
              React.createElement('div', { className: 'inner' })
            )
          )
        )
      );
    }
  }, {
    key: 'onClose',
    value: function onClose() {
      this.setState({ isHidden: true });
      this.refs.popupOverlay.hide();
      if (this.props.id) {
        localStorage['react-hint-' + this.props.id] = true;
      }
      if (this.props.onClose) {
        this.props.onClose();
      }
    }
  }, {
    key: 'getPopupPlacement',
    value: function getPopupPlacement() {
      return this.props.popupDirection || 'right';
    }
  }, {
    key: 'getDirectionBasedOffset',
    value: function getDirectionBasedOffset(rect) {
      var dir = this.props.position || 'topright';
      var x = rect.left;
      var y = rect.top;

      // decide position based on given position string
      if (dir === 'topright') {
        x = rect.right - this.width / 2;
        y = rect.top - this.height / 2;
      }
      if (dir === 'top') {
        x = rect.left + rect.width / 2 - this.width / 2;
        y = rect.top - this.height / 2;
      }
      if (dir === 'topleft') {
        x = rect.left - this.width / 2;
        y = rect.top - this.height / 2;
      }
      if (dir === 'left') {
        x = rect.left - this.width / 2;
        y = rect.top + rect.height / 2 - this.height / 2;
      }
      if (dir === 'bottomleft') {
        x = rect.left - this.width / 2;
        y = rect.bottom - this.height / 2;
      }
      if (dir === 'bottom') {
        x = rect.left + rect.width / 2 - this.width / 2;
        y = rect.bottom - this.height / 2;
      }
      if (dir === 'bottomright') {
        x = rect.right - this.width / 2;
        y = rect.bottom - this.height / 2;
      }
      if (dir === 'right') {
        x = rect.right - this.width / 2;
        y = rect.top + rect.height / 2 - this.height / 2;
      }

      // just add offsets, if any
      x += this.props.offsetX || 0;
      y += this.props.offsetY || 0;

      return { x: x, y: y };
    }
  }]);

  return Hint;
}(React.Component);

Hint.propTypes = process.env.NODE_ENV !== "production" ? {
  id: PropTypes.string.isRequired,
  message: PropTypes.node.isRequired,
  closeText: PropTypes.string,
  position: PropTypes.string,
  popupDirection: PropTypes.string,
  onClose: PropTypes.func,
  byID: PropTypes.string,
  isHidden: PropTypes.bool,

  children: PropTypes.node,
  offsetX: PropTypes.number,
  offsetY: PropTypes.number
} : {};

export default Hint;
